PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/tests.h File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Functions
tests.h File Reference
`#include "sbt.h"`
Include dependency graph for tests.h:

Go to the source code of this file.

## Functions
double | Ylmr (int l, int m, double theta, double phi)
double | Ylmi (int l, int m, double theta, double phi)
int | fft_check (char *wavecar, double *kpt_weights, int *fftg)

## Function Documentation

int fft_check | ( | char * | wavecar,
|  | double * | kpt_weights,
|  | int * | fftg
| ) |  |

double Ylmi | ( | int | l,
|  | int | m,
|  | double | theta,
|  | double | phi
| ) |  |

double Ylmr | ( | int | l,
|  | int | m,
|  | double | theta,
|  | double | phi
| ) |  |